<?php

namespace SGalinski\TypoScriptReferenceFrontend\Domain\Model;

/**
 * Attribute
 */
class Attribute {
	/**
	 * Constant used in $typo3Group field.
	 */
	const NORMAL_GROUP = 1;

	/**
	 * Constant used in $typo3Group field.
	 */
	const PAGE_GROUP = 2;

	/**
	 * Constant used in $typo3Group field.
	 */
	const USER_GROUP = 3;

	/**
	 * @var integer
	 */
	private $id;

	/**
	 * @var string
	 */
	private $name;

	/**
	 * @var string
	 */
	private $description;

	/**
	 * @var string The TYPO3 version in which the attribute was introduced
	 * Example: "4.5" "6.1" "6.2"), NULL is default and NULL is interpreted as most early version.
	 */
	private $minVersion = NULL;

	/**
	 * @var string Last TYPO3 version in which the attribute existed.
	 * A version after which the attribute was deprecated.
	 * Example: "4.5" "6.1" "6.2"), NULL is default and is interpreted as latest version.
	 */
	private $maxVersion = NULL;

	/**
	 * @var integer 3 = USER_GROUP, 2 = PAGE_GROUP, 1 = NORMAL_GROUP
	 */
	private $typo3Group = Attribute::NORMAL_GROUP;

	/**
	 * @var Attribute
	 */
	private $type;

	/**
	 * @var Attribute
	 */
	private $parent;

//	/**
//	 * @var ArrayCollection
//	 */
//	private $children;

	/**
	 * @var string
	 */
	private $default;

	/**
	 * @var boolean
	 */
	private $isType;

	/**
	 * @var boolean
	 */
	private $deleted = FALSE;

	/**
	 * Get id
	 *
	 * @return integer
	 */
	public function getId() {
		return $this->id;
	}

	/**
	 * Set name
	 *
	 * @param string $name
	 * @return Attribute
	 */
	public function setName($name) {
		$this->name = $name;

		return $this;
	}

	/**
	 * Get name
	 *
	 * @return string
	 */
	public function getName() {
		return $this->name;
	}

	/**
	 * Set description
	 *
	 * @param string $description
	 * @return Attribute
	 */
	public function setDescription($description) {
		$this->description = $description;

		return $this;
	}

	/**
	 * Get description
	 *
	 * @return string
	 */
	public function getDescription() {
		return $this->description;
	}

	/**
	 * Set minVersion
	 *
	 * @param string $minVersion
	 * @return Attribute
	 */
	public function setMinVersion($minVersion) {
		$this->minVersion = $minVersion;

		return $this;
	}

	/**
	 * Get minVersion
	 *
	 * @return string
	 */
	public function getMinVersion() {
		return $this->minVersion;
	}

	/**
	 * @return string
	 */
	public function getMaxVersion() {
		return $this->maxVersion;
	}

	/**
	 * @param string $maxVersion
	 * @return Attribute
	 */
	public function setMaxVersion($maxVersion) {
		$this->maxVersion = $maxVersion;

		return $this;
	}

	/**
	 * Set typo3Group
	 *
	 * @param integer $typo3Group
	 * @return Attribute
	 */
	public function setTypo3Group($typo3Group) {
		$this->typo3Group = $typo3Group;

		return $this;
	}

	/**
	 * Get typo3Group
	 *
	 * @return integer
	 */
	public function getTypo3Group() {
		return $this->typo3Group;
	}

	/**
	 * Set parent
	 *
	 * @param Attribute $parent
	 * @return Attribute
	 */
	public function setParent($parent) {
		$this->parent = $parent;

		return $this;
	}

	/**
	 * Get parent
	 *
	 * @return Attribute
	 */
	public function getParent() {
		return $this->parent;
	}

//	/**
//	 * Set children
//	 *
//	 * @param ArrayCollection $children
//	 * @return Attribute
//	 */
//	public function setChildren($children) {
//		$this->children = $children;
//
//		return $this;
//	}
//
//	/**
//	 * Get children
//	 *
//	 * @return ArrayCollection
//	 */
//	public function getChildren() {
//		return $this->children;
//	}
//
//	/**
//	 * Adds one child to the list.
//	 *
//	 * @param Attribute $child
//	 */
//	public function addChild(Attribute $child) {
//		$this->children[] = $child;
//	}

	/**
	 * Set isType
	 *
	 * @param boolean $isType
	 * @return Attribute
	 */
	public function setIsType($isType) {
		$this->isType = $isType;

		return $this;
	}

	/**
	 * Get isType
	 *
	 * @return boolean
	 */
	public function getIsType() {
		return $this->isType;
	}

	/**
	 * Set deleted
	 *
	 * @param boolean $deleted
	 * @return Attribute
	 */
	public function setDeleted($deleted) {
		$this->deleted = $deleted;

		return $this;
	}

	/**
	 * Get deleted
	 *
	 * @return boolean
	 */
	public function getDeleted() {
		return $this->deleted;
	}

	/**
	 * @return Attribute
	 */
	public function getType() {
		return $this->type;
	}

	/**
	 * @param Attribute $type
	 * @return Attribute
	 */
	public function setType($type) {
		$this->type = $type;

		return $this;
	}

	/**
	 * @return string
	 */
	public function getDefault() {
		return $this->default;
	}

	/**
	 * @param string $default
	 * @return Attribute
	 */
	public function setDefault($default) {
		$this->default = $default;

		return $this;
	}

	/**
	 * Writes object properties to associative array. NULL and not-set properties are ignored.
	 *
	 * @return array
	 */
	public function toArray() {
		$attributeArray = [];
		if (isset($this->id)) {
			$attributeArray ['id'] = $this->id;
		}
		if (isset($this->name)) {
			$attributeArray ['name'] = $this->name;
		}
		if (isset($this->description)) {
			$attributeArray ['description'] = $this->description;
		}
		if (isset($this->default)) {
			$attributeArray ['default'] = $this->default;
		}
		if (isset($this->minVersion)) {
			$attributeArray ['minVersion'] = $this->minVersion;
		}
		if (isset($this->maxVersion)) {
			$attributeArray ['maxVersion'] = $this->maxVersion;
		}
		if (isset($this->parent)) {
			$attributeArray ['parent'] = $this->parent->getId();
		}
		if (isset($this->type)) {
			$attributeArray ['type'] = $this->type->getId();
		}
		if (isset($this->typo3Group)) {
			$attributeArray ['typo3Group'] = $this->typo3Group;
		}
		if (isset($this->deleted)) {
			$attributeArray ['deleted'] = $this->deleted;
		}
		if (isset($this->isType)) {
			$attributeArray ['isType'] = $this->isType;
		}
		return $attributeArray;
	}
}
